@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2021-2022 Constantine Evans <const@costi.eu>
+#
+# SPDX-License-Identifier: AGPL-3.0-only
+
 from __future__ import annotations
 
 import asyncio
@@ -26,7 +30,7 @@ from .base import MachineStatus, RunStatus
 
 log = logging.getLogger(__name__)
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from .experiment import Experiment
     import matplotlib.pyplot as plt
 
